package com.esignlive.guidance.forum;

import java.util.Arrays;
import java.util.Collection;

import com.alibaba.fastjson.JSON;
import com.silanis.esl.sdk.ConditionalField;
import com.silanis.esl.sdk.Document;
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.Field;
import com.silanis.esl.sdk.FieldCondition;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.Signature;
import com.silanis.esl.sdk.SignatureId;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.FieldBuilder;
import com.silanis.esl.sdk.builder.FieldConditionBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SignatureBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;

public class _09_27_PositionExtractionExample {

	public static final String API_KEY = "your_api_key";
	public static final String API_URL = "https://sandbox.esignlive.com/api";
	public static final String FILE_PATH = "../Position Extraction Sample PDF.pdf";



	public static void main(String[] args) {
		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		//Create Transaction
		DocumentPackage newPackage = PackageBuilder.newPackageNamed("Example Transaction")
				.withSigner(SignerBuilder.newSignerWithEmail("signer1@mailinator.com")
						.withFirstName("John")
						.withLastName("Smith")
						.withCustomId("Signer1"))
				.withDocument(DocumentBuilder.newDocumentWithName("Document1")
						.fromFile(FILE_PATH)
						.enableExtraction()
						.withSignature(SignatureBuilder.signatureFor("signer1@mailinator.com")
								.withName("Signature1")
								.withPositionExtracted()
								//check box
								.withField(FieldBuilder.checkBox()
										.withPositionExtracted()
										.withName("CheckBox1"))
								//text field
								.withField(FieldBuilder.textField()
										.withPositionExtracted()
										.withName("TextField1"))
						)
				).build();
		PackageId packageId = eslClient.createPackageOneStep(newPackage);
		
		//Get document,signature and field IDs
		DocumentPackage draftPackage = eslClient.getPackage(packageId);
		String documentId = null;
		String signatureId = null;
		String checkBoxId = null;
		String textFieldId = null;
		Field draftCheckbox = null;
		for (Document document : draftPackage.getDocuments()) {
			if("Document1".equals(document.getName())) {
				documentId = document.getId().getId();
				for (Signature signature : document.getSignatures()) {
					signatureId = signature.getId().getId();
					if("Signature1".equals(signature.getName())) {
						for (Field field : signature.getFields()) {
							switch(field.getName()) {
								case "CheckBox1":
									draftCheckbox = field;
									checkBoxId = field.getId().getId();
									System.out.println(JSON.toJSONString(field));
									break;
								case "TextField1":
									textFieldId = field.getId().getId();
									break;
							}
						}
					}
				}
			}
		}
		
		//Add a condition
		if(draftCheckbox != null && documentId != null && checkBoxId != null && textFieldId != null) {
			FieldCondition newRadioButtoncondition1 = FieldConditionBuilder.newFieldCondition()
					.withId("Condition1")
					.withCondition("document['"+documentId+"'].field['"+checkBoxId+"'].value == 'X'")
					.withAction("document['"+documentId+"'].field['"+textFieldId+"'].disabled = false")
					.build();
			ConditionalField conditionalField = fieldToConditionalField(draftCheckbox);
			conditionalField.setConditions(Arrays.asList(newRadioButtoncondition1));
			eslClient.getApprovalService().updateConditionalField(packageId, documentId, new SignatureId(signatureId), conditionalField);
		}
		
		//send package
		eslClient.sendPackage(packageId);
		System.out.println(packageId);

	}

	private static ConditionalField fieldToConditionalField(Field field) {
		ConditionalField conditionalField = new ConditionalField();
		conditionalField.setExtraction(field.isExtraction()); 
		conditionalField.setFieldValidator(field.getFieldValidator());
		conditionalField.setFontSize(field.getFontSize());
		conditionalField.setHeight(field.getHeight());
		conditionalField.setId(field.getId());
		conditionalField.setName(field.getName());
		conditionalField.setPage(field.getPage());
		conditionalField.setStyle(field.getStyle());
//		conditionalField.setTextAnchor(field.getTextAnchor());		//text anchor is only useful when uploading the document
		conditionalField.setValue(field.getValue());
		conditionalField.setWidth(field.getWidth());
		conditionalField.setX(field.getX());
		conditionalField.setY(field.getY());
		return conditionalField;
	}
	
}